Package mt5se provides access to Stock Exchanges to python programs through Metatrader and some brokers. It can be used with NYSE,Nasdaq, B3(Brazilian Stock Exchange). For instance, you may access Nasdaq and NYSE with TradeView broker and you may access B3 with XP, Clear,Rico and others...

It allows access to price data (open, close, high, low) and book data (bid, ask) and It also allows order submission and management!!

Pyhton Framework for Autonomous Traders based on AI (mt5se)
==========================================


Documentation
=============

Read the documentation online at https://paulo-al-castro.github.io/mt5se/

Source code
===========

https://github.com/paulo-al-castro/mt5se

Contact
=======

paulo.al.castro@gmail.com